import ts from 'typescript';
import { createCustomModuleResolver } from './typescript/resolveModuleNames.js';
import { SourceFileManager } from './typescript/SourceFileManager.js';
import type { PrincipalOptions } from './PrincipalFactory.js';
import type { SyncCompilers, AsyncCompilers } from './types/compilers.js';
import type { ExportItem, ExportItemMember } from './types/exports.js';
import type { UnresolvedImport } from './types/imports.js';
import type { ProgramMaybe53 } from './typescript/SourceFile.js';
import type { GlobbyFilterFunction } from 'globby';
export declare class ProjectPrincipal {
    entryPaths: Set<string>;
    projectPaths: Set<string>;
    skipExportsAnalysis: Set<string>;
    isGitIgnored: GlobbyFilterFunction;
    cwd: string;
    compilerOptions: ts.CompilerOptions;
    extensions: Set<string>;
    syncCompilers: SyncCompilers;
    asyncCompilers: AsyncCompilers;
    backend: {
        fileManager: SourceFileManager;
        compilerHost: ts.CompilerHost;
        resolveModuleNames: ReturnType<typeof createCustomModuleResolver>;
        lsFindReferences: ts.LanguageService['findReferences'];
        program?: ProgramMaybe53;
    };
    constructor({ compilerOptions, cwd, compilers, isGitIgnored }: PrincipalOptions);
    private createProgram;
    private hasAcceptedExtension;
    addEntryPath(filePath: string, options?: {
        skipExportsAnalysis: boolean;
    }): void;
    addEntryPaths(filePaths: Set<string> | string[], options?: {
        skipExportsAnalysis: boolean;
    }): void;
    addProjectPath(filePath: string): void;
    runAsyncCompilers(): Promise<void>;
    getUsedResolvedFiles(): string[];
    private getProgramSourceFiles;
    getUnreferencedFiles(): string[];
    analyzeSourceFile(filePath: string, { skipTypeOnly, isFixExports, isFixTypes }: {
        skipTypeOnly: boolean;
        isFixExports: boolean;
        isFixTypes: boolean;
    }): {
        imports: {
            internal: import("./types/imports.js").Imports;
            unresolved: Set<UnresolvedImport>;
            external: Set<string>;
        };
        exports: {
            exported: import("./types/exports.js").ExportItems;
            duplicate: import("./types/issues.js").IssueSymbol[][];
        };
        scripts: Set<string>;
    };
    resolveModule(specifier: string, filePath?: string): ts.ResolvedModuleFull | undefined;
    getHasReferences(filePath: string, exportedItem: ExportItem): {
        external: boolean;
        internal: boolean;
    };
    findUnusedMembers(filePath: string, members: ExportItemMember[]): ExportItemMember[];
    private findReferences;
    getPos(node: ts.Node, pos: number): {
        line: number;
        col: number;
        pos: number;
    };
}
