import { _firstGlob } from '../../util/glob.js';
import { getValuesByKeyDeep } from '../../util/object.js';
import { basename, dirname, join } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { getDependenciesFromScripts, load } from '../../util/plugin.js';
function isString(value) {
    return typeof value === 'string';
}
export const NAME = 'GitHub Actions';
export const ENABLERS = 'This plugin is enabled when a `.yml` or `.yaml` file is found in the `.github/workflows` folder.';
export const isEnabled = async ({ cwd }) => Boolean(await _firstGlob({ cwd, patterns: ['.github/workflows/*.{yml,yaml}'] }));
export const CONFIG_FILE_PATTERNS = ['.github/workflows/*.{yml,yaml}', '.github/**/action.{yml,yaml}'];
const findGithubActionsDependencies = async (configFilePath, options) => {
    const { cwd, manifest, isProduction } = options;
    const configFileName = basename(configFilePath);
    if (isProduction)
        return [];
    const config = await load(configFilePath);
    if (!config)
        return [];
    const scripts = getValuesByKeyDeep(config, 'run').filter(isString);
    return [
        ...getActionDependencies(),
        ...getDependenciesFromScripts(scripts, {
            cwd,
            manifest,
            knownGlobalsOnly: true,
        }),
    ];
    function getActionDependencies() {
        const isActionManifest = configFileName === 'action.yml' || configFileName === 'action.yaml';
        if (!isActionManifest || !config?.runs?.using?.startsWith('node')) {
            return [];
        }
        const scripts = [config.runs.pre, config.runs.main, config.runs.post].filter(isString);
        return scripts.map(script => join(dirname(configFilePath), script));
    }
};
export const findDependencies = timerify(findGithubActionsDependencies);
