import { getGitHookPaths } from '../../util/git.js';
import { getValuesByKeyDeep } from '../../util/object.js';
import { extname } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { getDependenciesFromScripts, hasDependency, load, loadFile } from '../../util/plugin.js';
import { fromBinary } from '../../util/protocols.js';
export const NAME = 'Lefthook';
export const ENABLERS = ['lefthook', '@arkweid/lefthook', '@evilmartians/lefthook'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const gitHookPaths = getGitHookPaths();
export const CONFIG_FILE_PATTERNS = ['lefthook.yml', ...gitHookPaths];
const findLefthookDependencies = async (configFilePath, options) => {
    const { cwd, manifest, isProduction } = options;
    if (isProduction)
        return [];
    const dependencies = manifest.devDependencies ? Object.keys(manifest.devDependencies) : [];
    if (extname(configFilePath) === '.yml') {
        const localConfig = await load(configFilePath);
        if (!localConfig)
            return [];
        const scripts = getValuesByKeyDeep(localConfig, 'run').filter((run) => typeof run === 'string');
        const lefthook = process.env.CI ? ENABLERS.filter(dependency => dependencies.includes(dependency)) : [];
        return [...lefthook, ...getDependenciesFromScripts(scripts, { cwd, manifest, knownGlobalsOnly: true })];
    }
    const script = await loadFile(configFilePath);
    if (!script)
        return [];
    const scriptDependencies = getDependenciesFromScripts([script], { cwd, manifest, knownGlobalsOnly: false });
    const matches = scriptDependencies.find(dep => dependencies.includes(fromBinary(dep)));
    return matches ? [matches] : [];
};
export const findDependencies = timerify(findLefthookDependencies);
