import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { toEntryPattern } from '../../util/protocols.js';
import { findPlaywrightDependenciesFromConfig } from '../playwright/index.js';
export const NAME = 'Playwright for components';
export const ENABLERS = [/^@playwright\/experimental-ct-/];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['playwright-ct.config.{js,ts}', 'playwright/index.{js,ts,jsx,tsx}'];
export const ENTRY_FILE_PATTERNS = ['**/*.@(spec|test).?(c|m)[jt]s?(x)'];
const findPlaywrightCTDependencies = async (configFilePath, options) => {
    const { cwd, config } = options;
    const localConfig = await load(configFilePath);
    const defaultPatterns = (config?.entry ?? ENTRY_FILE_PATTERNS).map(toEntryPattern);
    if (localConfig) {
        return findPlaywrightDependenciesFromConfig({ config: localConfig, cwd, configFilePath, defaultPatterns });
    }
    return defaultPatterns;
};
export const findDependencies = timerify(findPlaywrightCTDependencies);
