import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
export const NAME = 'Stryker';
export const ENABLERS = ['@stryker-mutator/core'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['?(.)stryker.{conf,config}.{js,mjs,cjs,json}'];
const findStrykerDependencies = async (configFilePath, options) => {
    const { isProduction } = options;
    if (isProduction)
        return [];
    const localConfig = await load(configFilePath);
    if (!localConfig)
        return [];
    const runners = localConfig.testRunner ? [`@stryker-mutator/${localConfig.testRunner}-runner`] : [];
    const checkers = localConfig.checkers
        ? localConfig.checkers.map(checker => `@stryker-mutator/${checker}-checker`)
        : [];
    const plugins = localConfig.plugins ?? [];
    return [...runners, ...checkers, ...plugins];
};
export const findDependencies = timerify(findStrykerDependencies);
