import { basename, isInternal } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
export const NAME = 'Stylelint';
export const ENABLERS = ['stylelint'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = [
    '.stylelintrc',
    '.stylelintrc.{cjs,js,json,yaml,yml}',
    'stylelint.config.{cjs,mjs,js}',
];
const findPluginDependencies = async (configFilePath, options) => {
    const { manifest, isProduction } = options;
    if (isProduction)
        return [];
    const localConfig = basename(configFilePath) === 'package.json' ? manifest.stylelint : await load(configFilePath);
    if (!localConfig)
        return [];
    const extend = localConfig.extends ? [localConfig.extends].flat().filter(extend => !isInternal(extend)) : [];
    const plugins = localConfig.plugins ? [localConfig.plugins].flat().filter(plugin => !isInternal(plugin)) : [];
    return [...extend, ...plugins];
};
export const findDependencies = timerify(findPluginDependencies);
