import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { toEntryPattern, toProductionEntryPattern } from '../../util/protocols.js';
import { findWebpackDependenciesFromConfig } from '../webpack/index.js';
export const NAME = 'Vue';
export const ENABLERS = ['vue'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['vue.config.{js,ts}'];
export const ENTRY_FILE_PATTERNS = [];
export const PRODUCTION_ENTRY_FILE_PATTERNS = [];
export const PROJECT_FILE_PATTERNS = [];
const findPluginDependencies = async (configFilePath, options) => {
    const { config, isProduction, cwd, manifest } = options;
    const localConfig = await load(configFilePath);
    const deps = config.entry
        ? config.entry.map(toProductionEntryPattern)
        : [...ENTRY_FILE_PATTERNS.map(toEntryPattern), ...PRODUCTION_ENTRY_FILE_PATTERNS.map(toProductionEntryPattern)];
    if (isProduction || !localConfig)
        return deps;
    if (localConfig.configureWebpack) {
        const baseConfig = {
            mode: 'development',
            entry: {},
            resolve: {},
            plugins: [],
            module: { rules: [] },
        };
        const modifiedConfig = typeof localConfig.configureWebpack === 'function'
            ? localConfig.configureWebpack(baseConfig)
            : localConfig.configureWebpack;
        const { dependencies } = await findWebpackDependenciesFromConfig({
            config: modifiedConfig ?? baseConfig,
            cwd,
        });
        dependencies.forEach(dependency => deps.push(dependency));
    }
    if (!isProduction &&
        manifest.scripts &&
        Object.values(manifest.scripts).some(script => /(?<=^|\s)vue-cli-service(\s|\s.+\s)lint(?=\s|$)/.test(script))) {
        deps.push('@vue/cli-plugin-eslint');
    }
    return deps;
};
export const findDependencies = timerify(findPluginDependencies);
