import { ISSUE_TYPES } from '../constants.js';
import { ConfigurationError } from './errors.js';
const normalize = (values) => values.map(value => value.split(',')).flat();
export const getIncludedIssueTypes = (cliArgs, { include = [], exclude = [], isProduction = false } = {}) => {
    let incl = normalize(cliArgs.include);
    let excl = normalize(cliArgs.exclude);
    [...incl, ...excl, ...include, ...exclude].forEach(type => {
        if (!ISSUE_TYPES.includes(type))
            throw new ConfigurationError(`Invalid issue type: ${type}`);
    });
    const excludes = exclude.filter(exclude => !incl.includes(exclude));
    const includes = include.filter(include => !excl.includes(include));
    if (cliArgs.dependencies) {
        incl = [...incl, 'dependencies', 'optionalPeerDependencies', 'unlisted', 'binaries', 'unresolved'];
    }
    if (cliArgs.exports) {
        const exports = ['exports', 'nsExports', 'classMembers', 'types', 'nsTypes', 'enumMembers', 'duplicates'];
        incl = [...incl, ...exports];
    }
    const _include = [...incl, ...includes];
    const _exclude = [...excl, ...excludes];
    if (isProduction) {
        _exclude.push('devDependencies');
    }
    else {
        if (_include.includes('dependencies'))
            _include.push('devDependencies', 'optionalPeerDependencies');
        if (_exclude.includes('dependencies'))
            _exclude.push('devDependencies', 'optionalPeerDependencies');
    }
    const included = (_include.length > 0 ? _include : ISSUE_TYPES).filter(group => !_exclude.includes(group));
    return ISSUE_TYPES.reduce((types, group) => ((types[group] = included.includes(group)), types), {});
};
